# -*-coding:utf-8-*- #
# ---------------------------------------------------------------------------
# ProjectName:   test62
# FileName:      db.py
# Author:       why
# Datetime:     2024/9/7 上午10:07
# Description:
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# --------------------------------------------------------------------------
import pymysql

from apiAutoTest_v4 import log
from apiAutoTest_v4.common.read_project_ini import ReadProjectIni


class DB:
    def __init__(self):
        """链接数据库，创建链接对象、游标对象"""
        # 创建ReadProjectIni对象，获取数据库连接信息
        pro_ini = ReadProjectIni()
        self.conn = pymysql.connect(
            host=pro_ini.get_sql_connect_msg("host"),
            port=int(pro_ini.get_sql_connect_msg("port")),
            user=pro_ini.get_sql_connect_msg("user"),
            password=pro_ini.get_sql_connect_msg("password"),
            database=pro_ini.get_sql_connect_msg("database"),
            charset="utf8"
        )
        self.cursor = self.conn.cursor()

    def delete(self, sql_st):
        """使用db类对象，执行删除的sql语句"""
        # 判断输入的sql语句是否为字符串格式
        if isinstance(sql_st, str):
            # 判断sql语句是否以delete开头和;结尾：
            if sql_st.strip().lower().startswith("delete") and sql_st.strip().lower().endswith(";"):
                try:
                    # 执行sql语句
                    self.cursor.execute(sql_st)
                    self.conn.commit()
                except Exception as e:
                    log.error(f"执行删除的sql语句{sql_st}失败，错误为{e}")
                    raise e
            else:
                log.error(f"删除的sql语句{sql_st}格式错误")
                raise ValueError("sql语句错误")
        else:
            log.error(f"传入的sql语句{sql_st}不为字符串")
            raise ValueError("请传入字符串格式的sql语句！")

    def select(self, sql_st, n=0):
        """使用db类对象，执行查询的sql语句"""
        # 判断输入的sql语句是否为字符串格式
        if isinstance(sql_st, str):
            # 判断sql语句是否以select开头和;结尾：
            if sql_st.strip().lower().startswith("select") and sql_st.strip().lower().endswith(";"):
                try:
                    # 执行sql语句
                    self.cursor.execute(sql_st)
                except Exception as e:
                    log.error(f"执行查询的sql语句{sql_st}失败，错误为{e}")
                    raise e
                else:
                    select_res = self.cursor.fetchall()
                # 判断传入n是否为整数且查询结果是否为空，满足条件则返回查询值，不满足返回默认值None
                if isinstance(n, int) and select_res:
                    try:
                        return select_res[n][0]
                    except Exception as e:
                        log.error(f"执行select方法查询结果失败，传入sql语句为{sql_st}，传入形参n为{n}，错误为{e}")
                        raise e

            else:
                log.error(f"查询的sql语句{sql_st}格式错误")
                raise ValueError("sql语句错误")
        else:
            log.error(f"传入的sql语句{sql_st}不为字符串")
            raise ValueError("请传入字符串格式的sql语句！")

    def __del__(self):
        self.cursor.close()
        self.conn.close()