# -*-coding:utf-8-*- #
# ---------------------------------------------------------------------------
# ProjectName:   test62
# FileName:      read_excel.py
# Author:       why
# Datetime:     2024/9/7 上午10:35
# Description:
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# --------------------------------------------------------------------------
import openpyxl

from apiAutoTest_v4 import log
from apiAutoTest_v4.common.read_json import read_json
from apiAutoTest_v4.common.read_project_ini import ReadProjectIni
from apiAutoTest_v4.common.read_user_ini import ReadUserIni
from apiAutoTest_v4.data_config.settings import *


class ReadExcel:
    def __init__(self, user_dir_name):
        """获取所有json文件路径并读取，创建excel对象，获取excel文件路径，加载工作簿，获取工作表"""
        # 创建ReadUserIni对象，调用get_file_path方法获取文件路径
        user_ini = ReadUserIni(user_dir_name)
        # 获取json文件路径
        case_path = user_ini.get_file_path(FILE_CASE)
        expect_path = user_ini.get_file_path(FILE_EXPECT)
        sql_path = user_ini.get_file_path(FILE_SQL)
        # 读取json文件
        self.case_dict = read_json(case_path)
        self.expect_dict = read_json(expect_path)
        self.sql_dict = read_json(sql_path)
        # 获取excel路径和工作表名
        excel_path = user_ini.get_file_path(FILE_EXCEL)
        table_name = user_ini.get_table_name(TABLE_kEY)
        # 创建excel对象，加载工作簿，获取工作表
        try:
            wb = openpyxl.load_workbook(excel_path)
            self.ws = wb[table_name]
        except Exception as e:
            log.error(f"加载工作簿或获取工作表错误，传入excel路径为{excel_path}，工作表名称为{table_name}，错误为{e}")
            raise e
        # 创建ReadProjectIni对象，方便后续调用get_host方法
        self.pro_ini = ReadProjectIni()

    def __get_cell_value(self, column, row):
        """根据列号行号获取每个单元格的数据"""
        try:
            cell_value = self.ws[column+str(row)].value
        except Exception as e:
            log.error(f"获取单元格数据时产生错误，传入列号{column}、行号{row}，错误为{e}")
            raise e
        else:
            # 判断单元格数据是否为空，如为空返回默认值None，不为空则去掉空格后返回
            if cell_value is None:
                return None
            elif cell_value.strip():
                return cell_value.strip()

    def module_name(self, row):
        """根据行号获取模块名"""
        return self.__get_cell_value(MODULE, row)

    def api_name(self, row):
        """根据行号获取接口名"""
        return self.__get_cell_value(API, row)

    def case_url(self, row):
        """根据行号，获取用例数据的url"""
        path = self.__get_cell_value(URL, row)
        # 判断path是否为空，不为空则与host拼接，返回完整的url
        if path:
            return self.pro_ini.get_host(HOST_KEY) + path

    def case_req_method(self, row):
        """根据行号获取请求方法"""
        return self.__get_cell_value(REQ_METHOD, row)

    def case_mime(self, row):
        """根据行号获取请求媒体类型"""
        mime = self.__get_cell_value(MIME, row)
        if mime:
            return mime.lower()

    def case_data(self, row):
        """根据行号获取用例数据的key，再根据用例数据的key获取用例json文件中的数据"""
        case_data_key = self.__get_cell_value(CASE_DATA, row)
        # 根据用例数据的key，获取json文件中的用例数据
        if case_data_key:
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            return self.case_dict[module_name][api_name][case_data_key]

    def expect_data(self, row):
        """根据行号获取期望数据的key，再根据期望数据的key获取期望json文件中的数据"""
        expect_data_key = self.__get_cell_value(EXPECT_DATA, row)
        # 根据期望数据的key，获取json文件中的期望数据
        if expect_data_key:
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            return self.expect_dict[module_name][api_name][expect_data_key]

    def sql_data(self, row):
        """根据行号获取sql数据的key，再根据sql数据的key获取sql数据json文件中的数据"""
        sql_data_key = self.__get_cell_value(SQL_DATA, row)
        # 根据sql数据的key，获取json文件中的sql数据
        if sql_data_key:
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            return self.sql_dict[module_name][api_name][sql_data_key]

    def sql_type(self, row):
        """根据行号获取sql语句类型"""
        sql_type = self.__get_cell_value(SQL_TYPE, row)
        if sql_type:
            return sql_type.lower()

    def update_key(self, row):
        """根据行号获取要更新的key"""
        return self.__get_cell_value(UPDATE_KEY, row)

    def case_title(self, row):
        """根据行号获取用例数据标题"""
        return self.__get_cell_value(TITLE, row)

    def case_level(self, row):
        """根据行号获取用例等级"""
        return self.__get_cell_value(LEVEL, row)

    def get_data(self):
        """获取所有数据，并存放在一个二维列表中"""
        # 创建一个空列表，存放所有数据
        list_data = []
        # 循环所有行，获取每行的用例数据
        for row in range(2, self.ws.max_row+1):
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            title = self.case_title(row)
            level = self.case_level(row)
            url = self.case_url(row)
            method = self.case_req_method(row)
            mime = self.case_mime(row)
            case_data = self.case_data(row)
            expect_data = self.expect_data(row)
            sql_type = self.sql_type(row)
            sql_data = self.sql_data(row)
            update_key = self.update_key(row)
            # 过滤空行：如果url、请求方法、期望数据不为空，则该用例不为空?
            if url is not None and method is not None and expect_data is not None:
                list_data.append([module_name, api_name, title, level, url, method, mime, case_data, expect_data, sql_type, sql_data, update_key])
        else:
            return list_data


if __name__ == '__main__':
    excel = ReadExcel("demo")
    print(excel.get_data())
